@@ -1,10 +1,9 @@
-use chrono::Duration;
 use http_signature_normalization::create::Signed;
 use reqwest::{
     header::{InvalidHeaderValue, ToStrError},
     Request, RequestBuilder,
 };
-use std::fmt::Display;
+use std::{fmt::Display, time::Duration};
 
 pub use http_signature_normalization::RequiredError;
 
